@@ -1,10 +1,24 @@
+from .anilistpy import *
 from anilistpy.anime import Anime
 from anilistpy.manga import Manga
-from anilistpy.search.manga import mangaSearch
-from anilistpy.search.anime import animeSearch
+from anilistpy.char import Character
+from anilistpy.staff import Staff
+from anilistpy.studio import Studio
+
+from anilistpy.sr_manga import mangaSearch
+from anilistpy.sr_anime import animeSearch
+from anilistpy.sr_char import charSearch
+from anilistpy.sr_staff import searchStaff
+from anilistpy.sr_studio import searchStudio
+from anilistpy.utils import videoLink
+
+from anilistpy.mt_media import Media
+from anilistpy.mt_user import User
+
+from anilistpy.usr_medialist import MediaList 
 
 '''
-    <one line to give the program's name and a brief idea of what it does.>
+    easy to use wrapper for anilist apiv2
     Copyright (C) 2020  0kalekale
 
     This program is free software: you can redistribute it and/or modify
@@ -19,4 +33,4 @@ from anilistpy.search.anime import animeSearch
 
     You should have received a copy of the GNU Affero General Public License
     along with this program.  If not, see <https://www.gnu.org/licenses/>.
-'''
\ No newline at end of file
+'''
